@@ -22,50 +22,56 @@
 #include "todo.h"
 #include "event.h"
 #include "attachment.h"
+#include "utils.h"
 
-#include <qtest.h>
+#include <QTest>
 QTEST_MAIN(TodoTest)
 
 using namespace KCalCore;
 
+void TodoTest::initTestCase()
+{
+    qputenv("TZ", "GMT");
+}
+
 void TodoTest::testValidity()
 {
     QDate dt = QDate::currentDate();
     Todo *todo = new Todo();
-    todo->setDtStart(KDateTime(dt));
-    todo->setDtDue(KDateTime(dt).addDays(1));
+    todo->setDtStart(QDateTime(dt, {}));
+    todo->setDtDue(QDateTime(dt, {}).addDays(1));
     todo->setSummary(QStringLiteral("To-do1 Summary"));
     todo->setDescription(QStringLiteral("This is a description of the first to-do"));
     todo->setLocation(QStringLiteral("the place"));
     todo->setPercentComplete(5);
-    //KDE5: QVERIFY( todo->typeStr() == i18n( "to-do" ) );
-    QVERIFY(todo->summary() == QLatin1String("To-do1 Summary"));
-    QVERIFY(todo->location() == QLatin1String("the place"));
-    QVERIFY(todo->percentComplete() == 5);
+
+    QCOMPARE(todo->summary(), QStringLiteral("To-do1 Summary"));
+    QCOMPARE(todo->location(), QStringLiteral("the place"));
+    QCOMPARE(todo->percentComplete(), 5);
 }
 
 void TodoTest::testCompare()
 {
     QDate dt = QDate::currentDate();
     Todo todo1;
-    todo1.setDtStart(KDateTime(dt));
-    todo1.setDtDue(KDateTime(dt).addDays(1));
+    todo1.setDtStart(QDateTime(dt, {}));
+    todo1.setDtDue(QDateTime(dt, {}).addDays(1));
     todo1.setSummary(QStringLiteral("To-do1 Summary"));
     todo1.setDescription(QStringLiteral("This is a description of the first to-do"));
     todo1.setLocation(QStringLiteral("the place"));
     todo1.setCompleted(true);
 
     Todo todo2;
-    todo2.setDtStart(KDateTime(dt).addDays(1));
-    todo2.setDtDue(KDateTime(dt).addDays(2));
+    todo2.setDtStart(QDateTime(dt, {}).addDays(1));
+    todo2.setDtDue(QDateTime(dt, {}).addDays(2));
     todo2.setSummary(QStringLiteral("To-do2 Summary"));
     todo2.setDescription(QStringLiteral("This is a description of the second to-do"));
     todo2.setLocation(QStringLiteral("the other place"));
     todo2.setCompleted(false);
 
     QVERIFY(!(todo1 == todo2));
-    QVERIFY(todo1.dtDue() == todo2.dtStart());
-    QVERIFY(todo2.summary() == QLatin1String("To-do2 Summary"));
+    QCOMPARE(todo1.dtDue(), todo2.dtStart());
+    QCOMPARE(todo2.summary(), QStringLiteral("To-do2 Summary"));
     QVERIFY(!(todo1.isCompleted() == todo2.isCompleted()));
 }
 
@@ -73,26 +79,26 @@ void TodoTest::testClone()
 {
     QDate dt = QDate::currentDate();
     Todo todo1;
-    todo1.setDtStart(KDateTime(dt));
-    todo1.setDtDue(KDateTime(dt).addDays(1));
+    todo1.setDtStart(QDateTime(dt, {}));
+    todo1.setDtDue(QDateTime(dt, {}).addDays(1));
     todo1.setSummary(QStringLiteral("Todo1 Summary"));
     todo1.setDescription(QStringLiteral("This is a description of the first todo"));
     todo1.setLocation(QStringLiteral("the place"));
 
     Todo *todo2 = todo1.clone();
-    QVERIFY(todo1.summary() == todo2->summary());
-    QVERIFY(todo1.dtStart() == todo2->dtStart());
-    QVERIFY(todo1.dtDue() == todo2->dtDue());
-    QVERIFY(todo1.description() == todo2->description());
-    QVERIFY(todo1.location() == todo2->location());
-    QVERIFY(todo1.isCompleted() == todo2->isCompleted());
+    QCOMPARE(todo1.summary(), todo2->summary());
+    QCOMPARE(todo1.dtStart(), todo2->dtStart());
+    QCOMPARE(todo1.dtDue(), todo2->dtDue());
+    QCOMPARE(todo1.description(), todo2->description());
+    QCOMPARE(todo1.location(), todo2->location());
+    QCOMPARE(todo1.isCompleted(), todo2->isCompleted());
 }
 
 void TodoTest::testCopyIncidence()
 {
     QDate dt = QDate::currentDate();
     Event event;
-    event.setDtStart(KDateTime(dt));
+    event.setDtStart(QDateTime(dt, {}));
     event.setSummary(QStringLiteral("Event1 Summary"));
     event.setDescription(QStringLiteral("This is a description of the first event"));
     event.setLocation(QStringLiteral("the place"));
@@ -109,8 +115,8 @@ void TodoTest::testAssign()
 {
     QDate dt = QDate::currentDate();
     Todo todo1;
-    todo1.setDtStart(KDateTime(dt));
-    todo1.setDtDue(KDateTime(dt).addDays(1));
+    todo1.setDtStart(QDateTime(dt, {}));
+    todo1.setDtDue(QDateTime(dt, {}).addDays(1));
     todo1.setSummary(QStringLiteral("Todo1 Summary"));
     todo1.setDescription(QStringLiteral("This is a description of the first todo"));
     todo1.setLocation(QStringLiteral("the place"));
@@ -121,15 +127,14 @@ void TodoTest::testAssign()
 
 void TodoTest::testSetCompleted()
 {
-
     Todo todo1, todo2, todo3;
     todo1.setSummary(QStringLiteral("Todo Summary"));
     todo2.setSummary(QStringLiteral("Todo Summary"));
     todo3.setSummary(QStringLiteral("Todo Summary"));
-    KDateTime today = KDateTime::currentUtcDateTime();
+    QDateTime today = QDateTime::currentDateTimeUtc();
 
     // due yesterday
-    KDateTime originalDueDate = today.addDays(-1);
+    QDateTime originalDueDate = today.addDays(-1);
 
     todo1.setDtStart(originalDueDate);
     todo1.setDtDue(originalDueDate);
@@ -151,8 +156,8 @@ void TodoTest::testSetCompleted()
 
 void TodoTest::testStatus()
 {
-    KDateTime today = KDateTime::currentUtcDateTime();
-    KDateTime yesterday = today.addDays(-1);
+    QDateTime today = QDateTime::currentDateTimeUtc();
+    QDateTime yesterday = today.addDays(-1);
 
     Todo todo1;
     todo1.setDtStart(yesterday);
@@ -166,7 +171,7 @@ void TodoTest::testStatus()
 
     Todo todo2 = todo1;
     todo2.setPercentComplete(33);
-    todo2.setDtDue(KDateTime());
+    todo2.setDtDue(QDateTime());
     QVERIFY(todo2.isOpenEnded());
 }
 
@@ -174,8 +179,8 @@ void TodoTest::testSerializer_data()
 {
     QTest::addColumn<KCalCore::Todo::Ptr>("todo");
 
-    KDateTime today = KDateTime::currentUtcDateTime();
-    KDateTime yesterday = today.addDays(-1);
+    QDateTime today = QDateTime::currentDateTimeUtc();
+    QDateTime yesterday = today.addDays(-1);
 
     Todo::Ptr todo1 = Todo::Ptr(new Todo());
     Todo::Ptr todo2 = Todo::Ptr(new Todo());
@@ -201,8 +206,12 @@ void TodoTest::testSerializer_data()
 
     todo3->setDtStart(today);
     todo3->setPercentComplete(100);
-    todo3->setCategories(QStringList() << QStringLiteral("a") << QStringLiteral("b") << QStringLiteral("c") << QStringLiteral("d"));
-    todo3->setResources(QStringList() << QStringLiteral("a") << QStringLiteral("b") << QStringLiteral("c") << QStringLiteral("d"));
+    todo3->setCategories(QStringList()
+                         << QStringLiteral("a") << QStringLiteral("b")
+                         << QStringLiteral("c") << QStringLiteral("d"));
+    todo3->setResources(QStringList()
+                        << QStringLiteral("a") << QStringLiteral("b")
+                        << QStringLiteral("c") << QStringLiteral("d"));
     todo3->setPriority(5);
 
     QVERIFY(!todo4->dirtyFields().contains(IncidenceBase::FieldRecurrence));
@@ -264,14 +273,14 @@ void TodoTest::testSerializer()
 
 void TodoTest::testRoles()
 {
-    const KDateTime today = KDateTime::currentUtcDateTime();
-    const KDateTime yesterday = today.addDays(-1);
+    const QDateTime today = QDateTime::currentDateTimeUtc();
+    const QDateTime yesterday = today.addDays(-1);
     Todo todo;
     todo.setDtStart(today.addDays(-1));
     todo.setDtDue(today);
     QCOMPARE(todo.dateTime(Incidence::RoleDisplayStart), today);
     QCOMPARE(todo.dateTime(Incidence::RoleDisplayEnd), today);
-    todo.setDtDue(KDateTime());
+    todo.setDtDue(QDateTime());
     QCOMPARE(todo.dateTime(Incidence::RoleDisplayStart), yesterday);
     QCOMPARE(todo.dateTime(Incidence::RoleDisplayEnd), yesterday);
 }
